import oracledb from "oracledb";
/**
 * @description This method is use to execute sql query
 * @param query SQL query string to execute
 */
export declare const sqlExecute: (query: string) => Promise<oracledb.Result<unknown>>;
/**
 * @description This method gets all columns from a specified Database SQL Query
 *
 * @param response SQL query string to execute
 */
export declare const sqlGetAllColumns: (response: oracledb.Result<unknown>) => Promise<oracledb.Metadata<unknown>[] | undefined>;
/**
 * @description This method gets all rows from a specified Database SQL Query
 *
 * @param response SQL query string to execute
 */
export declare const sqlGetAllRows: (response: oracledb.Result<unknown>) => Promise<unknown[] | undefined>;
export declare class SQLModule {
    /**
     * @description This method is use to execute sql query
     * @param query SQL query string to execute
     * @param column specific column from the result - Optional
     * @param orderByColumn specific column from the result - Optional
     * @param sort sort order (ASC or DESC) - Optional
     * @param rowCount specific row number from the result - Optional
     */
    execute(dbParameters: {
        query: string;
        column?: string;
        orderByColumn?: string;
        sort?: string;
        rowCount?: number;
    }): Promise<oracledb.Result<unknown>>;
    /**
     * @description This method returns query result from specified column
     *
     * @param query SQL query string to execute
     * @param column specific column from the result
     */
    getSingleColumn(dbParameters: {
        query: string;
        column: string;
    }): Promise<oracledb.Result<unknown> | undefined>;
    /**
     * @description This method returns query result from specified column to be used for ascending order
     *
     * @param query SQL query string to execute
     * @param orderByColumn specific column from the result
     */
    sortAscending(dbParameters: {
        query: string;
        orderByColumn: string;
    }): Promise<oracledb.Result<unknown> | undefined>;
    /**
     * @description This method returns query result from specified column to be used for ascending order
     *
     * @param query SQL query string to execute
     * @param orderByColumn specific column to sort
     */
    sortDescending(dbParameters: {
        query: string;
        orderByColumn: string;
    }): Promise<oracledb.Result<unknown> | undefined>;
    /**
     * @description This method gets a specified number row from a result of Database SQL Query
     *
     * @param query SQL query string to execute
     * @param rowCount specific row number from the result
     */
    getSpecificRow(dbParameters: {
        query: string;
        rowCount: number;
    }): Promise<oracledb.Result<unknown> | undefined>;
}
declare const _default: SQLModule;
export default _default;
